@@ -1,4 +1,4 @@
-# $Id: Updater.pm 2301 2011-01-22 12:10:08Z guillomovitch $
+# $Id$
 
 package Youri::Package::RPM::Updater;
 
@@ -135,7 +135,7 @@ use SVN::Client;
 use Readonly;
 use YAML::AppConfig;
 use Youri::Package::RPM 0.002;
-use version; our $VERSION = qv('0.6.0');
+use version; our $VERSION = qv('0.6.2');
 use feature qw/switch/;
 
 # default values
@@ -467,7 +467,7 @@ sub _update_spec {
     my $old_version = $header->tag('version');
     return if $options{check_new_version} &&
               $new_version                &&
-              RPM4::rpmvercmp($old_version, $new_version) >= 0;
+              $wrapper_class->compare_revisions($old_version, $new_version) >= 0;
 
     my $new_release = $options{release} || '';
     my $epoch       = $header->tag('epoch');
@@ -883,7 +883,7 @@ sub _get_new_release_number {
             $value =~ /^(.*?)(\d+)($release_suffix)?$/;
 
         croak "Unable to extract release number from value '$value'"
-            unless $number;
+            unless defined($number);
 
         $number++;
     }
